@@ -1,5 +1,5 @@
 //  
-//  Copyright (C) 2009-2010 Jason Smith, Robert Dyer
+//  Copyright (C) 2009-2010 Jason Smith, Robert Dyer, Chris Szikszoy
 // 
 //  This program is free software: you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -15,22 +15,15 @@
 //  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // 
 
-using System;
-using System.Collections.Generic;
-using System.ComponentModel;
-using System.Linq;
-using System.Text;
 using System.Threading;
-using System.IO;
 
 using Mono.Unix;
-using NDesk.DBus;
 
-using Gdk;
+using DBus;
 using Gtk;
+using Notifications;
 
 using Docky.DBus;
-using Docky.Windowing;
 using Docky.Services;
 
 namespace Docky
@@ -58,36 +51,52 @@ namespace Docky
 			
 			//Init gtk and GLib related
 			Catalog.Init ("docky", AssemblyInfo.LocaleDirectory);
-			if (!GLib.Thread.Supported) GLib.Thread.Init ();
+			if (!GLib.Thread.Supported)
+				GLib.Thread.Init ();
 			Gdk.Threads.Init ();
-			NDesk.DBus.BusG.Init ();
 			Gtk.Application.Init ("Docky", ref args);
-			Gnome.Vfs.Vfs.Initialize ();
 			GLib.GType.Init ();
+			try {
+				BusG.Init ();
+			} catch {
+				Log.Fatal ("DBus could not be found and is required by Docky. Exiting.");
+				return;	
+			}
 			
 			// process the command line args
 			if (!UserArgs.Parse (args))
 				return;
 			
+			DockServices.Init ();
+			
 			Wnck.Global.ClientType = Wnck.ClientType.Pager;
 			
 			// set process name
 			DockServices.System.SetProcessName ("docky");
-			if (CheckForInstance ()) {
-				Log.Error ("Another Docky instance was detected - exiting.");
-				return;
-			}
 			
 			// cache main thread
-			SystemService.MainThread = Thread.CurrentThread;
+			DockServices.System.MainThread = Thread.CurrentThread;
 			
 			// check compositing
-			CheckComposite ();
+			CheckComposite (8);
 			Gdk.Screen.Default.CompositedChanged += delegate {
 				CheckComposite ();
 			};
 			
-			DBusManager.Default.Initialize ();
+			if (!DBusManager.Default.Initialize ()) {
+				Log.Fatal ("Another Docky instance was detected - exiting.");
+				return;	
+			}
+				
+			DBusManager.Default.QuitCalled += delegate {
+				Quit ();
+			};
+			DBusManager.Default.SettingsCalled += delegate {
+				ConfigurationWindow.Instance.Show ();
+			};
+			DBusManager.Default.AboutCalled += delegate {
+				ShowAbout ();
+			};
 			PluginManager.Initialize ();
 			Controller.Initialize ();
 			
@@ -98,20 +107,41 @@ namespace Docky
 			Controller.Dispose ();
 			DockServices.Dispose ();
 			PluginManager.Shutdown ();
-			Gnome.Vfs.Vfs.Shutdown ();
-		}
-		
-		static bool CheckForInstance ()
-		{
-			return Bus.Session.NameHasOwner ("org.gnome.Docky");
 		}
 		
+		static uint checkCompositeTimer = 0;
+		static Notification compositeNotify = null;
 		static void CheckComposite ()
 		{
-			GLib.Timeout.Add (2000, delegate {
+			CheckComposite (2);
+		}
+		
+		static void CheckComposite (uint timeout)
+		{
+			if (checkCompositeTimer != 0) {
+				GLib.Source.Remove (checkCompositeTimer);
+				checkCompositeTimer = 0;
+			}
+			
+			// compositing is enabled and we are still showing a notify, so close it
+			if (Gdk.Screen.Default.IsComposited && compositeNotify != null) {
+				compositeNotify.Close ();
+				compositeNotify = null;
+				return;
+			}
+			
+			checkCompositeTimer = GLib.Timeout.Add (timeout * 1000, delegate {
+				// no matter what, close any notify open
+				if (compositeNotify != null) {
+					compositeNotify.Close ();
+					compositeNotify = null;
+				}
+				
 				if (!Gdk.Screen.Default.IsComposited)
-					Log.Notify (Catalog.GetString ("Docky requires compositing to work properly. " +
-						"Please enable compositing and restart docky."));
+					compositeNotify = Log.Notify (Catalog.GetString ("Docky requires compositing to work properly. " +
+						"Certain options are disabled and themes/animations will look incorrect. "));
+				
+				checkCompositeTimer = 0;
 				return false;
 			});
 		}
@@ -265,7 +295,7 @@ namespace Docky
 				
 				"Ukrainian\n" +
 				" naker.ua\n";
-
+			
 			about.ShowAll ();
 			
 			about.Response += delegate {
